Index: wp-admin/import/livejournal.php
===================================================================
--- wp-admin/import/livejournal.php	(revision 14382)
+++ wp-admin/import/livejournal.php	(working copy)
@@ -220,7 +220,7 @@
 
 			</table>
 
-			<p><?php _e( "<strong>WARNING:</strong> This can take a really long time if you have a lot of entries in your LiveJournal, or a lot of comments. Ideally, you should only start this process if you can leave your computer alone while it finishes the import." ) ?></p>
+			<p><?php _e( "<strong>WARNING:</strong> This can take a really long time if you have alot of entries in your LiveJournal, or alot of comments. Ideally, you should only start this process if you can leave your computer alone while it finishes the import." ) ?></p>
 
 			<p class="submit">
 				<input type="submit" class="button" value="<?php esc_attr_e( 'Connect to LiveJournal and Import' ) ?>" />
Index: wp-admin/includes/file.php
===================================================================
--- wp-admin/includes/file.php	(revision 14382)
+++ wp-admin/includes/file.php	(working copy)
@@ -520,7 +520,7 @@
 	if ( ! $wp_filesystem || !is_object($wp_filesystem) )
 		return new WP_Error('fs_unavailable', __('Could not access filesystem.'));
 
-	// Unzip can use a lot of memory, but not this much hopefully
+	// Unzip can use alot of memory, but not this much hopefully
 	@ini_set('memory_limit', '256M');
 
 	$needed_dirs = array();
Index: wp-admin/install-helper.php
===================================================================
--- wp-admin/install-helper.php	(revision 14382)
+++ wp-admin/install-helper.php	(working copy)
@@ -7,7 +7,7 @@
  *
  * These functions are not optimized for speed, but they should only be used
  * once in a while, so speed shouldn't be a concern. If it is and you are
- * needing to use these functions a lot, you might experience time outs. If you
+ * needing to use these functions alot, you might experience time outs. If you
  * do, then it is advised to just write the SQL code yourself.
  *
  * You can turn debugging on, by setting $debug to 1 after you include this
Index: wp-includes/class-http.php
===================================================================
--- wp-includes/class-http.php	(revision 14382)
+++ wp-includes/class-http.php	(working copy)
@@ -1113,7 +1113,7 @@
  * HTTP request method uses HTTP extension to retrieve the url.
  *
  * Requires the HTTP extension to be installed. This would be the preferred transport since it can
- * handle a lot of the problems that forces the others to use the HTTP version 1.0. Even if PHP 5.2+
+ * handle alot of the problems that forces the others to use the HTTP version 1.0. Even if PHP 5.2+
  * is being used, it doesn't mean that the HTTP extension will be enabled.
  *
  * @package WordPress
Index: wp-includes/formatting.php
===================================================================
--- wp-includes/formatting.php	(revision 14382)
+++ wp-includes/formatting.php	(working copy)
@@ -379,7 +379,7 @@
 		return '';
 	}
 
-	// Don't bother if there are no entities - saves a lot of processing
+	// Don't bother if there are no entities - saves alot of processing
 	if ( strpos( $string, '&' ) === false ) {
 		return $string;
 	}
Index: wp-includes/kses.php
===================================================================
--- wp-includes/kses.php	(revision 14382)
+++ wp-includes/kses.php	(working copy)
@@ -459,7 +459,7 @@
 /**
  * Callback for wp_kses_split for fixing malformed HTML tags.
  *
- * This function does a lot of work. It rejects some very malformed things like
+ * This function does alot of work. It rejects some very malformed things like
  * <:::>. It returns an empty string, if the element isn't allowed (look ma, no
  * strip_tags()!). Otherwise it splits the tag into an element and an attribute
  * list.
@@ -604,7 +604,7 @@
 /**
  * Builds an attribute list from string containing attributes.
  *
- * This function does a lot of work. It parses an attribute list into an array
+ * This function does alot of work. It parses an attribute list into an array
  * with attribute data, and tries to do the right thing even if it gets weird
  * input. It will add quotes around attribute values that don't have any quotes
  * or apostrophes around them, to make it easier to produce HTML code that will
Index: wp-includes/plugin.php
===================================================================
--- wp-includes/plugin.php	(revision 14382)
+++ wp-includes/plugin.php	(working copy)
@@ -12,7 +12,7 @@
  * type are valid.
  *
  * Also see the {@link http://codex.wordpress.org/Plugin_API Plugin API} for
- * more information and examples on how to use a lot of these functions.
+ * more information and examples on how to use alot of these functions.
  *
  * @package WordPress
  * @subpackage Plugin
Index: wp-includes/post.php
===================================================================
--- wp-includes/post.php	(revision 14382)
+++ wp-includes/post.php	(working copy)
@@ -1437,7 +1437,7 @@
  *
  * This function provides an efficient method of finding the amount of post's
  * type a blog has. Another method is to count the amount of items in
- * get_posts(), but that method has a lot of overhead with doing so. Therefore,
+ * get_posts(), but that method has alot of overhead with doing so. Therefore,
  * when developing for 2.5+, use this function instead.
  *
  * The $perm parameter checks for 'readable' value and if the user can read
Index: wp-includes/taxonomy.php
===================================================================
--- wp-includes/taxonomy.php	(revision 14382)
+++ wp-includes/taxonomy.php	(working copy)
@@ -2106,7 +2106,7 @@
  *
  * It should be noted that update_object_term_cache() is very time extensive. It
  * is advised that the function is not called very often or at least not for a
- * lot of terms that exist in a lot of taxonomies. The amount of time increases
+ * lot of terms that exist in alot of taxonomies. The amount of time increases
  * for each term and it also increases for each taxonomy the term belongs to.
  *
  * @package WordPress

Index: wp-includes/rewrite.php
===================================================================
--- wp-includes/rewrite.php	(revision 14382)
+++ wp-includes/rewrite.php	(working copy)
@@ -613,7 +613,7 @@
 	/**
 	 * Whether to write every mod_rewrite rule for WordPress.
 	 *
 	 * This is off by default, turning it on might print a lot of rewrite rules
 	 * to the .htaccess file.
 	 *
 	 * @since 2.0.0
@@ -1493,7 +1493,7 @@
 					//allow URLs like <permalink>/2 for <permalink>/page/2
 					$match = $match . '(/[0-9]+)?/?$';
 					$query = $index . '?' . $query . '&page=' . $this->preg_index($num_toks + 1);
-				} else { //not matching a permalink so this is a lot simpler
+				} else { //not matching a permalink so this is alot simpler
 					//close the match and finalise the query
 					$match .= '?$';
 					$query = $index . '?' . $query;
@@ -613,7 +613,7 @@
 	 * Whether to write every mod_rewrite rule for WordPress.
 	 *
-	 * This is off by default, turning it on might print a lot of rewrite rules
+	 * This is off by default, turning it on might print alot of rewrite rules
 	 * to the .htaccess file.
 	 *